Contributing, Feature Requests, and Bug Reports
===============================================

Contributions and feedback are very welcome! We tried our best to make the **denofo** 
annotation format and `toolkit <https://github.com/EDohmen/denofo>`_ as open 
and easily accessible as possible and 
tested the toolkit extensively. However, there will always be some bugs on 
specific platforms or with specific combinations of hardware/software. Also, 
some bugs will sneak into the codebase over time with changes in our dependencies 
or features we add. If you find any bug or have trouble with our toolkit, 
please reach out to us either on `GitHub <https://github.com/EDohmen/denofo/discussions>`_ 
or via `email <mailto:e.dohmen@uni-muenster.de>`_. 
The more information you can provide about the error or bug, the faster we will 
be able to help you or fix it, but it does not matter if you know exactly what 
the issue is. We would still like to hear about all problems with **denofo**.

We are fully aware that de novo gene research is a very young and fast-moving 
field, where a large variety of methods and terms is used, and this makes it 
difficult to standardize everything to the satisfaction of everyone. 
We want to encourage the scientific community to discuss here also about all 
changes or novel developments of the field and how we can put these in better 
ways into the annotation format or the toolkit. If you are missing any features 
in the **denofo** `toolkit <https://github.com/EDohmen/denofo>`_  that would 
make your work easier or would be a great addition in your opinion, 
please let us know and we will try to implement them over time!